"""Module for styling terminal text."""
from .ansi import (
    in_black,
    in_blue,
    in_bold,
    in_cyan,
    in_green,
    in_magenta,
    in_red,
    in_white,
    in_yellow,
    on_black,
    on_blue,
    on_cyan,
    on_green,
    on_magenta,
    on_red,
    on_white,
    on_yellow,
    underlined,
    visual_len,
)
from .asap_print import asap_print
from .clear_line import clear_line
from .status import status
from .terminal_width import terminal_width

__all__ = [
    "asap_print",
    "clear_line",
    "in_black",
    "in_blue",
    "in_bold",
    "in_cyan",
    "in_green",
    "in_magenta",
    "in_red",
    "in_white",
    "in_yellow",
    "on_black",
    "on_blue",
    "on_cyan",
    "on_green",
    "on_magenta",
    "on_red",
    "on_white",
    "on_yellow",
    "status",
    "terminal_width",
    "underlined",
    "visual_len",
]

__version__ = "1.0.14"



from __future__ import print_function
import sys


def asap_print(*args, **kwargs):
    """
    Print to terminal immediately.

    Equivalent to calling print with `flush=True`.
    """
    if sys.version_info[:2] < (3, 3):
        print(*args, **kwargs)
        sys.stdout.flush()
    else:
        kwargs["flush"] = True
        print(*args, **kwargs)



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['terminology']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'terminology',
    'version': '1.0.14',
    'description': 'An intuitive way to color terminal text',
    'long_description': '# Terminology\n\n[![Build Status](https://travis-ci.org/juanrgon/terminology.svg?branch=master)](https://travis-ci.org/juanrgon/terminology)\n\nA simple way to color terminal text! ❤️ 💛 💚 💙 💜\n\n## Color Text\n\n```python\nfrom terminology import in_red, in_yellow, in_green, in_blue, in_magenta\n\nprint(in_red("it\'s"), in_yellow("a"), in_green("double"), in_blue("rainbow"), in_magenta("dude..."))\n```\n\n_Output_\n\n![alt text][coloring]\n\n[coloring]: https://raw.githubusercontent.com/juanrgon/terminology/master/pics/coloring.png\n "Coloring"\n\n## Color Text Background\n\n```python\nfrom terminology import on_green, on_yellow, on_red\n\nprint(on_green("OK"), on_yellow("WARNING"), on_red("DANGER")\n```\n\n_Output_\n\n![alt text][background colors]\n\n[background colors]: https://raw.githubusercontent.com/juanrgon/terminology/master/pics/background.png\n "Background Colors"\n\n## Emphasize Text with Bold and Underlining\n\n```python\nfrom terminology import in_bold, underlined\n\nprint(in_bold("Chapter 1"))\nprint("- ", underlined("Section i"))\nprint("- ", underlined("Section ii"), "\\n")\n\nprint(in_bold("Chapter 2"))\nprint("- ", underlined("Section i"), \'\\n\')\n```\n\n_Output_\n\n![alt text][bold and underline]\n\n[bold and underline]: https://raw.githubusercontent.com/juanrgon/terminology/master/pics/bold_and_underline.png\n "Bold and Underline"\n',
    'author': 'Juan Gonzalez',
    'author_email': 'jrg2156@gmail.com',
    'url': 'https://github.com/juanrgon/terminology',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
}


setup(**setup_kwargs)



from .asap_print import asap_print
from .clear_line import clear_line


def status(text=""):
    """
    Provide a status line.

    Usage:
       import time

       for seconds in range(10, 0, -1):
           status(f"Liftoff in {seconds}")
           time.sleep(1)
    """
    clear_line()
    asap_print(text, end="")
